@@ -14,7 +14,7 @@ with_mock_api({
              state_alpha = "VA"), 
       url = expected_url)
   })
-  
+
   test_that("nassqs forms a correct URL", {
     expect_GET(nassqs(params), url = expected_url)
   })
@@ -27,6 +27,20 @@ with_mock_api({
   test_that("nassqs_GET() works with lower case values", {
     expect_GET(nassqs(lower_params), url = expected_url)
   })
+  
+  expected_url <- "https://quickstats.nass.usda.gov/api/api_GET?key=API_KEY&agg_level_desc=STATE&commodity_desc=CORN&domaincat_desc=NOT%20SPECIFIED&state_alpha=CA&state_alpha=VA&statisticcat_desc=AREA%20HARVESTED&year=2012&format=CSV"
+  test_that("multiple parameter arguments yield the correct URL", {
+    expect_GET(
+      nassqs(commodity_desc = "CORN",
+             year = "2012",
+             agg_level_desc = "STATE",
+             statisticcat_desc = "AREA HARVESTED",
+             domaincat_desc = "NOT SPECIFIED",
+             state_alpha = c("CA", "VA")), 
+      url = expected_url)
+  })
+  
+  
 })
 
 
